@@ -117,12 +117,30 @@ class Panda::Ecosystem {
                $buf ~= $g;
             }
 
-
+            die "Got an empty metadata file." unless $buf.chars;
             $!projectsfile.IO.spurt: $buf;
         }
 
         CATCH {
-            die "Could not download module metadata: {$_.message}"
+            default {
+                note "Could not download module metadata: {$_.message}.";
+                note "Falling back to the curl command.";
+                run 'curl', $url, '-#', '-o', $!projectsfile;
+                die "Got an empty metadata file." unless $!projectsfile.IO.s;
+                CATCH {
+                    default {
+                        note "curl failed: {$_.message}.";
+                        note "Falling back to the wget command.";
+                        run 'wget', '-nv', '--unlink', $url, '-O', $!projectsfile;
+                        die "Got an empty metadata file." unless $!projectsfile.IO.s;
+                        CATCH {
+                            default {
+                                die "wget failed as well: {$_.message}. Sorry, have to give up."
+                            }
+                        }
+                    }
+                }
+            }
         }
     }
 
